## Scope

<!-- TODO: add Koheesio specifics -->
<!-- * NumPy docstrings inside the classes and modules -->
<!-- * Show some examples -->
<!-- * Modify the below to fit our need -->

## The System

We will be adopting "The Documentation System".

From [documentation.divio.com](https://documentation.divio.com):

> There is a secret that needs to be understood in order to write good software _documentation_: there isn’t one thing called documentation, there are four.
>
> They are: _tutorials, how-to guides, technical reference and explanation_. They represent four different purposes or functions, and require four different approaches to their creation. Understanding the implications of this will help improve most documentation - often immensely.
>
> **About the system**
> ![Documentation System Overview](../assets/documentation-system-overview.png)
> The documentation system outlined here is a simple, comprehensive and nearly universally-applicable scheme. It is proven in practice across a wide variety of fields and applications.
>
> There are some very simple principles that govern documentation that are very rarely if ever spelled out. They seem to be a secret, though they shouldn’t be.
>
> If you can put these principles into practice, **it will make your documentation better and your project, product or team more successful** - that’s a promise.
>
> [The system is widely adopted](https://documentation.divio.com/adoption.html#adoption) for large and small, open and proprietary documentation projects.
>
> Video Presentation on YouTube:
>
> [![Documentation System Video Presentation](http://img.youtube.com/vi/t4vKPhjcMZg/0.jpg)](http://www.youtube.com/watch?v=t4vKPhjcMZg "What nobody tells you about documentation")
